=======
History
=======

0.4.2 (2022-04-13)
------------------

* Fix compatibility with Python 3.9+


0.4.1 (2020-05-13)
------------------

* Fix: add compatibility with flake8 3.8.*

0.4.0 (2017-07-06)
------------------

* New: Add ``--htmlpep8`` option to produce normal flake8 console output
* Fix: Allow all ``flake8-html`` settings to be read from flake8 config


0.3.0 (2017-05-24)
------------------

* New: Add ``--htmltitle`` option to set page title


0.2.0 (2017-03-06)
------------------

* New: use SVG icons instead of Unicode characters
* New: deduplicate the same error on the same line


0.1.1 (2017-03-02)
------------------

* Fix: missing templates in sdist.


0.1.0 (2017-03-01)
------------------

* First release on PyPI.
